Analysis Parameters
===================

Contains analysis parameters, default values, and validation ranges for molecular interaction analysis.

Module Overview
---------------

.. automodule:: hbat.constants.parameters
   :members:
   :undoc-members:
   :show-inheritance:

Classes
-------

Parameters Default Values
~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: hbat.constants.parameters.ParametersDefault
   :members:
   :undoc-members:
   :show-inheritance:

Analysis Parameters
~~~~~~~~~~~~~~~~~~~

.. autoclass:: hbat.constants.parameters.AnalysisParameters
   :members:
   :undoc-members:
   :show-inheritance:

Parameter Validation Ranges
~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: hbat.constants.parameters.ParameterRanges
   :members:
   :undoc-members:
   :show-inheritance:

PDB Fixing Modes
~~~~~~~~~~~~~~~~~

.. autoclass:: hbat.constants.parameters.PDBFixingModes
   :members:
   :undoc-members:
   :show-inheritance:

Analysis Modes
~~~~~~~~~~~~~~

.. autoclass:: hbat.constants.parameters.AnalysisModes
   :members:
   :undoc-members:
   :show-inheritance:

Bond Detection Methods
~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: hbat.constants.parameters.BondDetectionMethods
   :members:
   :undoc-members:
   :show-inheritance: